#  Copyright 2009, Erik Hahn

#  This file is part of Ordnung.
#
#  Ordnung is free software: you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  Ordnung is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with Ordnung.  If not, see <http://www.gnu.org/licenses/>.

from lib import *

import os, sys
from path import path
from optparse import OptionParser, OptionGroup

ACTIONS = {
        "nothing": 0,
        "preview": 1,
        "copy": 2,
        "move": 3
        }

def main_cli(file):
    if not issupportedfile(file): return
    try:
        target = newpath(file, OPTIONS["pattern"], OPTIONS["windows"])
    except TagException:
        print _("Error reading tags from {0}").format(file)
        return

    if not samefile(file, target):
        if OPTIONS["action"] == ACTIONS["move"]:
            mkdir(tpath)
            try:
                shutil.move(file, target)
            except shutil.error:
                pass # In case samefile() fails on Windows
        elif OPTIONS["action"] == ACTIONS["copy"]:
            mkdir(tpath)
            try:
                shutil.copy2(file, target)
            except shutil.error:
                pass
        elif OPTIONS["action"] == ACTIONS["preview"]:
            safeprint (file + " --> " + target)


def main():
    # Gettext
    _ = gettext("cli")

    # Parse arguments
    usage = _("Usage: %prog [options] directory pattern")
    version = "Ordnung 0.1.1"
    parser = OptionParser(usage=usage, version=version)
    parser.add_option("-r", "--recursive", action="store_true",
            dest="recursive", default=False,
            help=_("also move/copy files from sub-directories"))
    if not os.name == "nt":
        parser.add_option("-w", "--windows", action="store_true", 
                dest="windows", default=False,
                help=_("generate Windows-compatible file and path names"))

    actions = OptionGroup(parser, "Possible actions")
    actions.add_option("--preview", "-p", action="store_const",
            const=ACTIONS["preview"], dest="action",
            help=_("preview, don't make any changes (default)"))
    actions.add_option("--copy", "-c", action="store_const",
            const=ACTIONS["copy"], dest="action", help=_("copy files"))
    actions.add_option("--move", "-m", action="store_const",
            const=ACTIONS["move"], dest="action", help=_("move files"))
    actions.add_option("--nothing", "-n", action="store_const",
            const=ACTIONS["nothing"], dest="action", help=_("do nothing (for debugging)"))
    parser.add_option_group(actions)
    (options, args) = parser.parse_args()
 
    if options.action is None:
        OPTIONS["action"] = ACTIONS["preview"]
    else:
        OPTIONS["action"] = options.action

    OPTIONS["recursive"] = options.recursive

    if os.name == "nt":
        OPTIONS["windows"] = True
    else:
        OPTIONS["windows"] = options.windows

    try:
        base = args[0]
        OPTIONS["pattern"] = args[1]
    except IndexError:
        print _("You must specify directory and pattern.")
        sys.exit()

    # TODO
    OPTIONS["gui"] = False

    # Do stuff
    if not OPTIONS["gui"]:
        if OPTIONS["recursive"]:
            for i in path(base).walkfiles(): main_cli(i)
        else:
            for i in path(base).files(): main_cli(i)


if __name__ == "__main__":
    main()
